package oop10;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * GridBagConstraints iin daha kolay kullanm sunan bir yardmc snf yazlabilir. 
 * Paketteki GBC snf da byle bir snftr.

 * GBC.gridx, gridy: 
 * 	Bileenin sol st kesi iin zgara koordinatlar.
 * 	Izgarann sol st (0,0), analitik sistemde 4. blge.
 * GBC.gridwidth, gridheight:
 * 	Bileenin ka stun ve ka satr kaplayaca.
 * 	HTML colspan ve rowspan gibi.
 * GBC.weightx, weighty:
 * 	Kalan bo alann yzde kann o stun/satrn o yndeki uzamasna atanaca. 
 *  Eer alan hi bymesin istiyorsan o yndekine 0 ver. Aksi halde 100 ver. 
 *  Ara deerler pek deneme-yanlma iin harcanan zamana demiyor.
 * 	NER: Her alana 100 ver, sonra eitli pencere ebatlarnda bymenin rahatsz 
 *  ettii bileen ve ynler iin 0 ver. 
 *  Dikkat: Alan diyoruz, yani stun veya satr. Bileen deil.
 */
 /**
 * GBC.fill:
 * 	Bileenin byyp tm alan kapsamasn istemiyorsan kullan.
 * 	Bu kstlama bymeye izin verilen ynleri belirtir. 
 * 	Deerler: GBC.NONE, GBC.HORIZONTAL, GBC.VERTICAL, GBC.BOTH
 * GBC.anchor:
 * 	GBC.fill ayarlar nedeniyle bymeyen bileenin o alanda
 * 	hangi konumda durmasn istiyorsan oray ver.
 * 	Deerler: GBC.CENTER (default), GBC.NORTHEAST, ... yani tm ana ve ara ynler.
 * 	1. gsterim:
 * 		NORTHWEST			NORTH			NORTHEAST
 * 		WEST				CENTER			EAST
 * 		SOUTHWEST			SOUTH			SOUTHEAST
 * 	2. gsterim:
 * 		FIRST_LINE_START	LINE_START		FIRST_LINE_END
 * 		PAGE_START			CENTER			PAGE_END
 * 		LAST_LINE_START		LINE_END		LAST_LINE_END
 * Yastklama (d):
 * 	Bileenin etrafnda ek bo alan olsun istiyorsan GBC.insets yesini olutur. 
 *  java.awt.Insets.Insets( int top, int left, int bottom, int right );
 * GBC.ipadx, ipady: 
 * 	 yastklama iin. Bileenin minimum boyutlar senin iin ok kkse bu 
 *  deerleri ver, bileenin min. boyutu eski min. boyut + yastk deeri olur.
 */
public class Layout04GridBagLayout {
	public static void main(String[] args)	{  
		EventQueue.invokeLater(new Runnable() {
			public void run() {
				Frame06 frame = new Frame06();
				frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
				frame.setVisible(true);
			}
		});
	}
}

/**
 A frame that uses a grid bag layout to arrange font selection components.
 */
class Frame06 extends JFrame
{  
	private static final long serialVersionUID = 1L;
	public static final int DEFAULT_WIDTH = 300;
	public static final int DEFAULT_HEIGHT = 200;  
	private JComboBox<String> face;
	private JComboBox<Integer> size;
	private JCheckBox bold;
	private JCheckBox italic;
	private JTextArea sample;

	public Frame06()
	{  
		setTitle("FontDialog");
		setSize(DEFAULT_WIDTH, DEFAULT_HEIGHT);
		
		GridBagLayout layout = new GridBagLayout();
		setLayout(layout);
		
		ActionListener listener = new FontAction();
		
		// construct components
		JLabel faceLabel = new JLabel("Face: ");
		face = new JComboBox<String>(new String[] { "Serif", "SansSerif", 
				"Monospaced", "Dialog", "DialogInput"  });
		face.addActionListener(listener);
		
		JLabel sizeLabel = new JLabel("Size: ");
		size = new JComboBox<Integer>(new Integer[] {
				8, 10, 12, 15, 18, 24, 36, 48 });
		size.addActionListener(listener);
		
		bold = new JCheckBox("Bold");
		bold.addActionListener(listener);
		italic = new JCheckBox("Italic");
		italic.addActionListener(listener);
		
		sample = new JTextArea();
		sample.setText("The quick brown fox jumps over the lazy dog");
		sample.setEditable(false);
		sample.setLineWrap(true);
		sample.setBorder(BorderFactory.createEtchedBorder());
		
		// add components to grid, using GBC convenience class
		// GBC constructor: (x,y) (not row, col)
		// if you wish (row, col), change your class accordingly
		add(faceLabel, new GBC(0, 0).setAnchor(GBC.EAST));
		add(face, new GBC(1, 0).setFill(GBC.HORIZONTAL).
				setWeight(100, 0).setInsets(1));
		add(sizeLabel, new GBC(0, 1).setAnchor(GBC.EAST));
		add(size, new GBC(1, 1).setFill(GBC.HORIZONTAL).
				setWeight(100, 0).setInsets(1));
		add(bold, new GBC(0, 2, 2, 1).setAnchor(GBC.CENTER).
				setWeight(100, 100));
		add(italic, new GBC(0, 3, 2, 1).setAnchor(GBC.CENTER).
				setWeight(100, 100));
		add(sample, new GBC(2, 0, 1, 4).setFill(GBC.BOTH).
				setWeight(100, 100));
	}
	
	/**
	 An action listener that changes the font of the 
	 sample text.
	 */
	private class FontAction implements ActionListener
	{
		public void actionPerformed(ActionEvent event)
		{  
			String fontFace = face.getItemAt( face.getSelectedIndex() );
			int fontStyle = (bold.isSelected() ? Font.BOLD : 0)
			+ (italic.isSelected() ? Font.ITALIC : 0);
			int fontSize = size.getItemAt( size.getSelectedIndex() );

			Font font = new Font(fontFace, fontStyle, fontSize);
			sample.setFont(font);
			sample.repaint();
		}
	}
}