package oop11;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import java.io.*;
import javax.swing.filechooser.FileFilter;


public class UIElements07_FileDialog extends JFrame {
	private static final long serialVersionUID = 1L;
	public static final int DEFAULT_WIDTH = 400;
	public static final int DEFAULT_HEIGHT = 200;  
	private JPanel panel, altPanel;
	private JFileChooser fileDialog;

	public static void main(String[] args) {
	      EventQueue.invokeLater(new Runnable() {
	          public void run() {
	        	 UIElements07_FileDialog frame = new UIElements07_FileDialog();
	             frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	             frame.setVisible(true);
	          }
	       });
	}

	public UIElements07_FileDialog() {
		setTitle("FileDialogTest");
		setSize(DEFAULT_WIDTH, DEFAULT_HEIGHT);
		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize(); 
		setLocation(screenSize.width/10,screenSize.height/10);
		panel = new JPanel();
		panel.setLayout( new BorderLayout() );
		final JLabel isim = new JLabel("Bir dosya anz.");
		panel.add(isim,BorderLayout.NORTH);
		final JTextArea metin = new JTextArea();
		JScrollPane scroll = new JScrollPane(metin);
		panel.add(scroll,BorderLayout.CENTER);
		altPanel = new JPanel();
		JButton openButton = new JButton("A");
		altPanel.add(openButton);
		openButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent event) {
				
				/* Adm 1: JFileChooser rnei olutur. */
				fileDialog = new JFileChooser();
				
				/* Adm 2: alma dizinini se. */
				fileDialog.setCurrentDirectory(new File("."));
				
				/* Adm 3: nceden seilmi bir dosya olsun
				 * istiyorsan setSelectedFile(new File(...))
				 * kullan. Daha ok Save dialog'u iin geerli
				 * nk olmayan dosya exception yapar. */
				
				/* Adm 4: Sadece belli dosya tipleri ile
				 * uramak istiyorsan FileFilter snfndan
				 * trettiin bir snftan rnei kullan. */
				fileDialog.setFileFilter( new FileTypes() );
				/* Birden fazla filtre eklemek istiyorsan
				 * addChooseableFileFilter kullanabilirsin. */
				
				/* Adm 5: Dosya tipleri arasna *.* (all files)
				 * otomatik eklenir. stemiyorsan alttakini kullan.
				 * */
				//fileDialog.setAcceptAllFileFilterUsed(false);
				
				/* Adm 6: A veya Kaydet diyalou istemene 
				 * gre showOpenDialog(Component parent) veya
				 * showSaveDialog(Component parent);
				 * Parent burada mecburi, null verme.
				 * ki metodun arasndaki tek fark ana dmenin
				 * "Open" veya "Save" olarak kmasdr. 
				 * Kendi dme etiketini istiyorsan 
				 * showDialog(parent,"Etiket") kullan. */
				int result = fileDialog.showOpenDialog(UIElements07_FileDialog.this);

				/* Dier olas dn seenekleri 
				 * JFileChooser.CANCEL_OPTION veya
				 * JFileChooser.ERROR_OPTION olabilir.
				 * Seilen dosyay simgeleyen File rneini
				 * almak iin getSelectedFile() kullan.
				 * */
				if( result == JFileChooser.APPROVE_OPTION ) {
					String line = fileDialog.getSelectedFile().getPath();
					String metinStr = new String();
					isim.setText("Dosya: "+line);
					try {
						BufferedReader bri = new BufferedReader( 
								new FileReader( fileDialog.getSelectedFile() ));
						line = bri.readLine();
						while( line != null ) {
							metinStr += line + "\n";
							line = bri.readLine();
						}
						bri.close();
						metin.setText( metinStr );
					}
					catch( FileNotFoundException e ) {
						JOptionPane.showMessageDialog(null,"Dosya Bulunamad", "Dosya Hatas", 
								JOptionPane.ERROR_MESSAGE);
					}
					catch( IOException e ) {
						JOptionPane.showMessageDialog(null,"Dosya Okunamad", "Dosya Hatas", JOptionPane.ERROR_MESSAGE);
					}
				}
			}
		});
		JButton saveButton = new JButton("Farkl Kaydet");
		altPanel.add(saveButton);
		saveButton.addActionListener( new ActionListener() {
			public void actionPerformed(ActionEvent event) {
				fileDialog.setSelectedFile(new File (isim.getText()));
				int result = fileDialog.showSaveDialog(UIElements07_FileDialog.this);
				if( result == JFileChooser.APPROVE_OPTION ) {
					String line = fileDialog.getSelectedFile().getPath();
					isim.setText("Dosya: "+line);
					try {
						BufferedWriter bwi = new BufferedWriter( new FileWriter( fileDialog.getSelectedFile() ));
						bwi.write( metin.getText());
						bwi.close();
					}
					catch( FileNotFoundException e ) {
						JOptionPane.showMessageDialog(null,"Dosya Bulunamad", "Dosya Hatas", JOptionPane.ERROR_MESSAGE);
					}
					catch( IOException e ) {
						JOptionPane.showMessageDialog(null,"Dosya Okunamad", "Dosya Hatas", JOptionPane.ERROR_MESSAGE);
					}
				}
			}
		});
		panel.add(altPanel, BorderLayout.SOUTH);
		add(panel);
	}
	
	private class FileTypes extends FileFilter {
		public boolean accept( File f ) {
			String[] myTypes = new String[] {
				".txt", ".csv", ".bat", ".java"
			};
			if( f.isDirectory() )
				return true;
			for( String anExtension: myTypes )
				if( f.getName().toLowerCase().endsWith(anExtension) )
					return true;
			return false;
		}
		public String getDescription( ) {
			return "Metin tabanl eitli dosyalar";
		}
	}
}
